@@ -12,7 +12,7 @@ from pyvista._version import __version__
 from pyvista.plotting import *
 from pyvista.utilities import *
 from pyvista.core import *
-from pyvista.utilities.misc import _get_vtk_id_type, vtk_version_info
+from pyvista.utilities.misc import _get_vtk_id_type, vtk_version_info, _set_plot_theme_from_env
 from pyvista import _vtk
 from pyvista.jupyter import set_jupyter_backend, PlotterITK
 from pyvista.themes import set_plot_theme, load_theme, _rcParams
@@ -27,8 +27,7 @@ global_theme = _GlobalTheme()
 rcParams = _rcParams()  # raises DeprecationError when used
 
 # Set preferred plot theme
-if 'PYVISTA_PLOT_THEME' in os.environ:
-    set_plot_theme(os.environ['PYVISTA_PLOT_THEME'].lower())
+_set_plot_theme_from_env()
 
 # get the int type from vtk
 ID_TYPE = _get_vtk_id_type()
@@ -43,12 +42,7 @@ if vtk_version_info.major < 5:  # pragma: no cover
 warnings.simplefilter(action='ignore', category=FutureWarning)
 
 # A simple flag to set when generating the documentation
-OFF_SCREEN = False
-try:
-    if os.environ['PYVISTA_OFF_SCREEN'].lower() == 'true':
-        OFF_SCREEN = True
-except KeyError:
-    pass
+OFF_SCREEN = os.environ.get("PYVISTA_OFF_SCREEN", "false").lower() == "true"
 
 # If available, a local vtk-data instance will be used for examples
 VTK_DATA_PATH: Optional[str] = None
@@ -104,6 +98,11 @@ except Exception as e:
     )
     EXAMPLES_PATH = ''
 
+# verify example cache integrity
+from pyvista.examples.downloads import _verify_cache_integrity
+
+_verify_cache_integrity()
+
 # Send VTK messages to the logging module:
 send_errors_to_logging()
 
