@@ -41,6 +41,8 @@ class DeprecationError(RuntimeError):
 class VTKVersionError(RuntimeError):
     """Requested feature is not supported by the installed VTK version."""
 
-    def __init__(self, message='The requested feature is not supported by the installed VTK version.'):
+    def __init__(
+        self, message='The requested feature is not supported by the installed VTK version.'
+    ):
         """Empty init."""
         RuntimeError.__init__(self, message)
