@@ -11,7 +11,8 @@ from pyvista import _vtk
 from pyvista.core.dataset import DataSet
 from pyvista.core.filters import UniformGridFilters, _get_output
 from pyvista.utilities import abstract_class
-from pyvista.utilities.misc import PyvistaDeprecationWarning
+import pyvista.utilities.helpers as helpers
+from pyvista.utilities.misc import PyvistaDeprecationWarning, raise_has_duplicates
 
 log = logging.getLogger(__name__)
 log.setLevel('CRITICAL')
@@ -68,12 +69,31 @@ class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid):
 
     Can be initialized in several ways:
 
-    - Create empty grid
-    - Initialize from a vtk.vtkRectilinearGrid object
-    - Initialize directly from the point arrays
+    * Create empty grid
+    * Initialize from a ``vtk.vtkRectilinearGrid`` object
+    * Initialize directly from the point arrays
 
-    See _from_arrays in the documentation for more details on initializing
-    from point arrays
+    Parameters
+    ----------
+    uinput : str, pathlib.Path, vtk.vtkRectilinearGrid, numpy.ndarray, optional
+        Filename, dataset, or array to initialize the rectilinear grid from. If a
+        filename is passed, pyvista will attempt to load it as a
+        :class:`RectilinearGrid`. If passed a ``vtk.vtkRectilinearGrid``, it
+        will be wrapped. If a :class:`numpy.ndarray` is passed, this will be
+        loaded as the x range.
+
+    y : numpy.ndarray, optional
+        Coordinates of the points in y direction. If this is passed, ``uinput``
+        must be a :class:`numpy.ndarray`.
+
+    z : numpy.ndarray, optional
+        Coordinates of the points in z direction. If this is passed, ``uinput``
+        and ``y`` must be a :class:`numpy.ndarray`.
+
+    check_duplicates : bool, optional
+        Check for duplications in any arrays that are passed. Defaults to
+        ``False``. If ``True``, an error is raised if there are any duplicate
+        values in any of the array-valued input arguments.
 
     Examples
     --------
@@ -81,7 +101,7 @@ class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid):
     >>> import vtk
     >>> import numpy as np
 
-    Create an empty grid
+    Create an empty grid.
 
     >>> grid = pyvista.RectilinearGrid()
 
@@ -90,7 +110,7 @@ class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid):
     >>> vtkgrid = vtk.vtkRectilinearGrid()
     >>> grid = pyvista.RectilinearGrid(vtkgrid)
 
-    Create from NumPy arrays
+    Create from NumPy arrays.
 
     >>> xrng = np.arange(-10, 10, 2)
     >>> yrng = np.arange(-10, 10, 5)
@@ -101,7 +121,7 @@ class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid):
 
     _WRITERS = {'.vtk': _vtk.vtkRectilinearGridWriter, '.vtr': _vtk.vtkXMLRectilinearGridWriter}
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, check_duplicates=False, **kwargs):
         """Initialize the rectilinear grid."""
         super().__init__()
 
@@ -109,9 +129,9 @@ class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid):
             if isinstance(args[0], _vtk.vtkRectilinearGrid):
                 self.deep_copy(args[0])
             elif isinstance(args[0], (str, pathlib.Path)):
-                self._from_file(args[0])
+                self._from_file(args[0], **kwargs)
             elif isinstance(args[0], np.ndarray):
-                self._from_arrays(args[0], None, None)
+                self._from_arrays(args[0], None, None, check_duplicates)
             else:
                 raise TypeError(f'Type ({type(args[0])}) not understood by `RectilinearGrid`')
 
@@ -124,9 +144,9 @@ class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid):
                 arg2_is_arr = False
 
             if all([arg0_is_arr, arg1_is_arr, arg2_is_arr]):
-                self._from_arrays(args[0], args[1], args[2])
+                self._from_arrays(args[0], args[1], args[2], check_duplicates)
             elif all([arg0_is_arr, arg1_is_arr]):
-                self._from_arrays(args[0], args[1], None)
+                self._from_arrays(args[0], args[1], None, check_duplicates)
             else:
                 raise TypeError("Arguments not understood by `RectilinearGrid`.")
 
@@ -142,7 +162,9 @@ class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid):
         """Update the dimensions if coordinates have changed."""
         return self.SetDimensions(len(self.x), len(self.y), len(self.z))
 
-    def _from_arrays(self, x: np.ndarray, y: np.ndarray, z: np.ndarray):
+    def _from_arrays(
+        self, x: np.ndarray, y: np.ndarray, z: np.ndarray, check_duplicates: bool = False
+    ):
         """Create VTK rectilinear grid directly from numpy arrays.
 
         Each array gives the uniques coordinates of the mesh along each axial
@@ -151,26 +173,32 @@ class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid):
 
         Parameters
         ----------
-        x : np.ndarray
+        x : numpy.ndarray
             Coordinates of the points in x direction.
 
-        y : np.ndarray
+        y : numpy.ndarray
             Coordinates of the points in y direction.
 
-        z : np.ndarray
+        z : numpy.ndarray
             Coordinates of the points in z direction.
 
+        check_duplicates : bool, optional
+            Check for duplications in any arrays that are passed.
+
         """
         # Set the coordinates along each axial direction
         # Must at least be an x array
-        x = np.unique(x.ravel())
-        self.SetXCoordinates(_vtk.numpy_to_vtk(x))
+        if check_duplicates:
+            raise_has_duplicates(x)
+        self.SetXCoordinates(helpers.convert_array(x.ravel()))
         if y is not None:
-            y = np.unique(y.ravel())
-            self.SetYCoordinates(_vtk.numpy_to_vtk(y))
+            if check_duplicates:
+                raise_has_duplicates(y)
+            self.SetYCoordinates(helpers.convert_array(y.ravel()))
         if z is not None:
-            z = np.unique(z.ravel())
-            self.SetZCoordinates(_vtk.numpy_to_vtk(z))
+            if check_duplicates:
+                raise_has_duplicates(z)
+            self.SetZCoordinates(helpers.convert_array(z.ravel()))
         # Ensure dimensions are properly set
         self._update_dimensions()
 
@@ -254,12 +282,12 @@ class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid):
         array([-10.,   0.,  10.])
 
         """
-        return _vtk.vtk_to_numpy(self.GetXCoordinates())
+        return helpers.convert_array(self.GetXCoordinates())
 
     @x.setter
     def x(self, coords: Sequence):
         """Set the coordinates along the X-direction."""
-        self.SetXCoordinates(_vtk.numpy_to_vtk(coords))
+        self.SetXCoordinates(helpers.convert_array(coords))
         self._update_dimensions()
         self.Modified()
 
@@ -287,12 +315,12 @@ class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid):
         array([-10.,   0.,  10.])
 
         """
-        return _vtk.vtk_to_numpy(self.GetYCoordinates())
+        return helpers.convert_array(self.GetYCoordinates())
 
     @y.setter
     def y(self, coords: Sequence):
         """Set the coordinates along the Y-direction."""
-        self.SetYCoordinates(_vtk.numpy_to_vtk(coords))
+        self.SetYCoordinates(helpers.convert_array(coords))
         self._update_dimensions()
         self.Modified()
 
@@ -320,12 +348,12 @@ class RectilinearGrid(_vtk.vtkRectilinearGrid, Grid):
         array([-10.,   0.,  10.])
 
         """
-        return _vtk.vtk_to_numpy(self.GetZCoordinates())
+        return helpers.convert_array(self.GetZCoordinates())
 
     @z.setter
     def z(self, coords: Sequence):
         """Set the coordinates along the Z-direction."""
-        self.SetZCoordinates(_vtk.numpy_to_vtk(coords))
+        self.SetZCoordinates(helpers.convert_array(coords))
         self._update_dimensions()
         self.Modified()
 
@@ -580,7 +608,7 @@ class UniformGrid(_vtk.vtkImageData, Grid, UniformGridFilters):
         --------
         >>> import pyvista
         >>> grid = pyvista.UniformGrid(dims=(2, 2, 2))
-        >>> grid.y
+        >>> grid.x
         array([0., 1., 0., 1., 0., 1., 0., 1.])
 
         """
@@ -734,5 +762,42 @@ class UniformGrid(_vtk.vtkImageData, Grid, UniformGridFilters):
         grid.point_data.update(self.point_data)
         grid.cell_data.update(self.cell_data)
         grid.field_data.update(self.field_data)
-        grid.copy_meta_from(self)
+        grid.copy_meta_from(self, deep=True)
         return grid
+
+    @property
+    def extent(self) -> tuple:
+        """Return or set the extent of the UniformGrid.
+
+        The extent is simply the first and last indices for each of the three axes.
+
+        Examples
+        --------
+        Create a ``UniformGrid`` and show its extent.
+
+        >>> import pyvista
+        >>> grid = pyvista.UniformGrid(dims=(10, 10, 10))
+        >>> grid.extent
+        (0, 9, 0, 9, 0, 9)
+
+        >>> grid.extent = (2, 5, 2, 5, 2, 5)
+        >>> grid.extent
+        (2, 5, 2, 5, 2, 5)
+
+        Note how this also modifies the grid bounds and dimensions. Since we
+        use default spacing of 1 here, the bounds match the extent exactly.
+
+        >>> grid.bounds
+        (2.0, 5.0, 2.0, 5.0, 2.0, 5.0)
+        >>> grid.dimensions
+        (4, 4, 4)
+
+        """
+        return self.GetExtent()
+
+    @extent.setter
+    def extent(self, new_extent: Sequence[int]):
+        """Set the extent of the UniformGrid."""
+        if len(new_extent) != 6:
+            raise ValueError('Extent must be a vector of 6 values.')
+        self.SetExtent(new_extent)
