@@ -2,16 +2,29 @@
 
 from pyvista import MAX_N_COLOR_BARS
 from .charts import Chart2D, ChartMPL, ChartBox, ChartPie
-from .colors import (color_char_to_word, get_cmap_safe, hex_to_rgb, hexcolors,
-                     string_to_rgb, PARAVIEW_BACKGROUND)
+from .colors import (
+    Color,
+    color_like,
+    color_char_to_word,
+    get_cmap_safe,
+    hex_to_rgb,
+    hexcolors,
+    string_to_rgb,
+    PARAVIEW_BACKGROUND,
+)
 from .export_vtkjs import export_plotter_vtkjs, get_vtkjs_url
 from .helpers import plot, plot_arrows, plot_compare_four, plot_itk
 from .plotting import BasePlotter, Plotter, close_all
 from .renderer import CameraPosition, Renderer, scale_point
-from .tools import (create_axes_marker, create_axes_orientation_box,
-                    opacity_transfer_function, FONTS,
-                    system_supports_plotting, parse_color,
-                    parse_font_family)
+from .tools import (
+    create_axes_marker,
+    create_axes_orientation_box,
+    opacity_transfer_function,
+    FONTS,
+    system_supports_plotting,
+    parse_color,
+    parse_font_family,
+)
 from .widgets import WidgetHelper
 from .lights import Light
 from .camera import Camera
@@ -33,7 +46,7 @@ class QtDeprecationError(Exception):
         Exception.__init__(self, self.message.format(*[feature_name] * 4))
 
 
-class BackgroundPlotter():
+class BackgroundPlotter:
     """This class has been moved to pyvistaqt."""
 
     def __init__(self, *args, **kwargs):
@@ -41,7 +54,7 @@ class BackgroundPlotter():
         raise QtDeprecationError('BackgroundPlotter')
 
 
-class QtInteractor():
+class QtInteractor:
     """This class has been moved to pyvistaqt."""
 
     def __init__(self, *args, **kwargs):
