@@ -9,15 +9,6 @@ from pyvista.utilities import get_array
 from .tools import opacity_transfer_function
 
 
-def _has_matplotlib():
-    try:
-        import matplotlib  # noqa
-
-        return True
-    except ImportError:  # pragma: no cover
-        return False
-
-
 def prepare_smooth_shading(mesh, scalars, texture, split_sharp_edges, feature_angle, preference):
     """Prepare a dataset for smooth shading.
 
