@@ -178,6 +178,7 @@ import pyvista
 from pyvista import _vtk
 from pyvista._typing import color_like
 from pyvista.utilities import PyvistaDeprecationWarning
+from pyvista.utilities.misc import has_module
 
 IPYGANY_MAP = {
     'reds': 'Reds',
@@ -945,43 +946,49 @@ def string_to_rgb(string):  # pragma: no cover
 
 def get_cmap_safe(cmap):
     """Fetch a colormap by name from matplotlib, colorcet, or cmocean."""
-    try:
-        from matplotlib.cm import get_cmap
-    except ImportError:  # pragma: no cover
-        raise ImportError(
-            'The use of custom colormaps requires the installation of matplotlib'
-        ) from None
-
     if isinstance(cmap, str):
         # check if this colormap has been mapped between ipygany
         if cmap in IPYGANY_MAP:
             cmap = IPYGANY_MAP[cmap]
 
         # Try colorcet first
-        try:
+        if has_module('colorcet'):
             import colorcet
 
-            cmap = colorcet.cm[cmap]
-        except (ImportError, KeyError):
-            pass
-        else:
-            return cmap
+            try:
+                return colorcet.cm[cmap]
+            except KeyError:
+                pass
+
         # Try cmocean second
-        try:
+        if has_module('cmocean'):
             import cmocean
 
-            cmap = getattr(cmocean.cm, cmap)
-        except (ImportError, AttributeError):
-            pass
-        else:
-            return cmap
+            try:
+                return getattr(cmocean.cm, cmap)
+            except AttributeError:
+                pass
+
         # Else use Matplotlib
+        if not has_module('matplotlib'):
+            raise ImportError(
+                'The use of custom colormaps requires the installation of matplotlib.'
+            )  # pragma: no cover
+
+        from matplotlib.cm import get_cmap
+
         cmap = get_cmap(cmap)
 
     elif isinstance(cmap, list):
         for item in cmap:
             if not isinstance(item, str):
                 raise TypeError('When inputting a list as a cmap, each item should be a string.')
+
+        if not has_module('matplotlib'):
+            raise ImportError(
+                'The use of custom colormaps requires the installation of matplotlib.'
+            )  # pragma: no cover
+
         from matplotlib.colors import ListedColormap
 
         cmap = ListedColormap(cmap)
