@@ -203,7 +203,7 @@ class Renderer(_vtk.vtkOpenGLRenderer):
         """Initialize the renderer."""
         super().__init__()
         self._actors = {}
-        self.parent = parent  # the plotter
+        self.parent = parent  # weakref.proxy to the plotter from Renderers
         self._theme = parent.theme
         self.camera_set = False
         self.bounding_box_actor = None
@@ -621,7 +621,14 @@ class Renderer(_vtk.vtkOpenGLRenderer):
         return self._actors
 
     def add_actor(
-        self, uinput, reset_camera=False, name=None, culling=False, pickable=True, render=True
+        self,
+        uinput,
+        reset_camera=False,
+        name=None,
+        culling=False,
+        pickable=True,
+        render=True,
+        remove_existing_actor=True,
     ):
         """Add an actor to render window.
 
@@ -653,6 +660,10 @@ class Renderer(_vtk.vtkOpenGLRenderer):
             If the render window is being shown, trigger a render
             after adding the actor.
 
+        remove_existing_actor : bool, optional
+            Removes any existing actor if the named actor ``name`` is already
+            present.
+
         Returns
         -------
         actor : vtk.vtkActor
@@ -662,7 +673,8 @@ class Renderer(_vtk.vtkOpenGLRenderer):
             Actor properties.
         """
         # Remove actor by that name if present
-        rv = self.remove_actor(name, reset_camera=False, render=False)
+        if name and remove_existing_actor:
+            rv = self.remove_actor(name, reset_camera=False, render=False)
 
         if isinstance(uinput, _vtk.vtkMapper):
             actor = _vtk.vtkActor()
@@ -705,7 +717,6 @@ class Renderer(_vtk.vtkOpenGLRenderer):
                 raise ValueError(f'Culling option ({culling}) not understood.')
 
         actor.SetPickable(pickable)
-        self.ResetCameraClippingRange()
         self.Modified()
 
         prop = None
@@ -1937,7 +1948,7 @@ class Renderer(_vtk.vtkOpenGLRenderer):
         self.camera_set = True
         self.Modified()
 
-    def set_viewup(self, vector):
+    def set_viewup(self, vector, reset=True):
         """Set camera viewup vector.
 
         Parameters
@@ -1945,6 +1956,10 @@ class Renderer(_vtk.vtkOpenGLRenderer):
         vector : sequence
             New 3 value camera viewup vector.
 
+        reset : bool, optional
+            Whether to reset the camera after setting the camera
+            position.
+
         Examples
         --------
         Look from the top down by setting view up to ``[0, 1, 0]``.
@@ -1959,7 +1974,11 @@ class Renderer(_vtk.vtkOpenGLRenderer):
         if isinstance(vector, np.ndarray):
             if vector.ndim != 1:
                 vector = vector.ravel()
+
         self.camera.up = vector
+        if reset:
+            self.reset_camera()
+
         self.camera_set = True
         self.Modified()
 
@@ -2273,6 +2292,9 @@ class Renderer(_vtk.vtkOpenGLRenderer):
             self.ResetCamera(*bounds)
         else:
             self.ResetCamera()
+
+        self.reset_camera_clipping_range()
+
         if render:
             self.parent.render()
         self.Modified()
@@ -2675,10 +2697,10 @@ class Renderer(_vtk.vtkOpenGLRenderer):
 
         self.SetBackground(Color(color, default_color=self._theme.background).float_rgb)
         if use_gradient:
-            self.GradientBackgroundOn()
+            self.SetGradientBackground(True)
             self.SetBackground2(Color(top).float_rgb)
         else:
-            self.GradientBackgroundOff()
+            self.SetGradientBackground(False)
         self.Modified()
 
     def set_environment_texture(self, texture, is_srgb=False):
@@ -2728,6 +2750,26 @@ class Renderer(_vtk.vtkOpenGLRenderer):
         self.SetEnvironmentTexture(texture, is_srgb)
         self.Modified()
 
+    def remove_environment_texture(self):
+        """Remove the environment texture.
+
+        Examples
+        --------
+        >>> from pyvista import examples
+        >>> import pyvista as pv
+        >>> pl = pv.Plotter(lighting=None)
+        >>> cubemap = examples.download_sky_box_cube_map()
+        >>> _ = pl.add_mesh(pv.Sphere(), pbr=True, metallic=0.9, roughness=0.4)
+        >>> pl.set_environment_texture(cubemap)
+        >>> pl.remove_environment_texture()
+        >>> pl.camera_position = 'xy'
+        >>> pl.show()
+
+        """
+        self.UseImageBasedLightingOff()
+        self.SetEnvironmentTexture(None)
+        self.Modified()
+
     def close(self):
         """Close out widgets and sensitive elements."""
         self.RemoveAllObservers()
@@ -2760,6 +2802,7 @@ class Renderer(_vtk.vtkOpenGLRenderer):
             self.disable_shadows()
         if self.__charts is not None:
             self.__charts.deep_clean()
+            self.__charts = None
 
         self.remove_floors(render=render)
         self.remove_legend(render=render)
@@ -2982,9 +3025,9 @@ class Renderer(_vtk.vtkOpenGLRenderer):
             self._legend.SetPosition2(size[0], size[1])
 
         if bcolor is None:
-            self._legend.UseBackgroundOff()
+            self._legend.SetUseBackground(False)
         else:
-            self._legend.UseBackgroundOn()
+            self._legend.SetUseBackground(True)
             self._legend.SetBackgroundColor(Color(bcolor).float_rgb)
 
         self._legend.SetBorder(border)
