@@ -1,7 +1,5 @@
 """Module dedicated to widgets."""
 
-from typing import List
-
 import numpy as np
 
 import pyvista
@@ -24,7 +22,23 @@ class WidgetHelper:
 
     """
 
-    _camera_widgets: List[object] = []
+    def __init__(self, *args, **kwargs):
+        """Initialize widget helper."""
+        super().__init__(*args, **kwargs)
+        self.camera_widgets = []
+        self.box_widgets = []
+        self.box_clipped_meshes = []
+        self.plane_widgets = []
+        self.plane_clipped_meshes = []
+        self.plane_sliced_meshes = []
+        self.line_widgets = []
+        self.slider_widgets = []
+        self.threshold_meshes = []
+        self.isovalue_meshes = []
+        self.spline_widgets = []
+        self.spline_sliced_meshes = []
+        self.sphere_widgets = []
+        self.button_widgets = []
 
     def add_box_widget(
         self,
@@ -36,6 +50,7 @@ class WidgetHelper:
         use_planes=False,
         outline_translation=True,
         pass_widget=False,
+        interaction_event=_vtk.vtkCommand.EndInteractionEvent,
     ):
         """Add a box widget to the scene.
 
@@ -81,15 +96,27 @@ class WidgetHelper:
             If ``True``, the widget will be passed as the last
             argument of the callback.
 
+        interaction_event : vtk.vtkCommand.EventIds, optional
+            The VTK interaction event to use for triggering the callback.
+
         Returns
         -------
         vtk.vtkBoxWidget
             Box widget.
 
-        """
-        if not hasattr(self, "box_widgets"):
-            self.box_widgets = []
+        Examples
+        --------
+        Shows an interactive clip box.
 
+        >>> import pyvista as pv
+        >>> mesh = pv.ParametricConicSpiral()
+        >>> pl = pv.Plotter()
+        >>> _ = pl.add_mesh_clip_box(mesh, color='white')
+        >>> pl.show()
+
+        For a full example see :ref:`box_widget_example`.
+
+        """
         if bounds is None:
             bounds = self.bounds
 
@@ -119,18 +146,15 @@ class WidgetHelper:
         box_widget.SetTranslationEnabled(outline_translation)
         box_widget.PlaceWidget(bounds)
         box_widget.On()
-        box_widget.AddObserver(_vtk.vtkCommand.EndInteractionEvent, _the_callback)
+        box_widget.AddObserver(interaction_event, _the_callback)
         _the_callback(box_widget, None)
 
         self.box_widgets.append(box_widget)
         return box_widget
 
     def clear_box_widgets(self):
-        """Disable all of the box widgets."""
-        if hasattr(self, 'box_widgets'):
-            for widget in self.box_widgets:
-                widget.Off()
-            del self.box_widgets
+        """Remove all of the box widgets."""
+        self.box_widgets.clear()
 
     def add_mesh_clip_box(
         self,
@@ -141,6 +165,7 @@ class WidgetHelper:
         outline_translation=True,
         merge_points=True,
         crinkle=False,
+        interaction_event=_vtk.vtkCommand.EndInteractionEvent,
         **kwargs,
     ):
         """Clip a mesh using a box widget.
@@ -183,6 +208,9 @@ class WidgetHelper:
         crinkle : bool, optional
             Crinkle the clip by extracting the entire cells along the clip.
 
+        interaction_event : vtk.vtkCommand.EventIds, optional
+            The VTK interaction event to use for triggering the callback.
+
         **kwargs : dict, optional
             All additional keyword arguments are passed to
             :func:`BasePlotter.add_mesh` to control how the mesh is
@@ -199,7 +227,7 @@ class WidgetHelper:
         kwargs.setdefault('clim', kwargs.pop('rng', rng))
         mesh.set_active_scalars(kwargs.get('scalars', mesh.active_scalars_name))
 
-        self.add_mesh(mesh.outline(), name=name + "outline", opacity=0.0)
+        self.add_mesh(mesh.outline(), name=f"{name}-outline", opacity=0.0)
 
         port = 1 if invert else 0
 
@@ -213,8 +241,6 @@ class WidgetHelper:
         alg.SetInputDataObject(mesh)
         alg.GenerateClippedOutputOn()
 
-        if not hasattr(self, "box_clipped_meshes"):
-            self.box_clipped_meshes = []
         box_clipped_mesh = pyvista.wrap(alg.GetOutput(port))
         self.box_clipped_meshes.append(box_clipped_mesh)
 
@@ -240,6 +266,7 @@ class WidgetHelper:
             use_planes=True,
             color=widget_color,
             outline_translation=outline_translation,
+            interaction_event=interaction_event,
         )
 
         return self.add_mesh(box_clipped_mesh, reset_camera=False, **kwargs)
@@ -260,6 +287,7 @@ class WidgetHelper:
         pass_widget=False,
         test_callback=True,
         normal_rotation=True,
+        interaction_event=_vtk.vtkCommand.EndInteractionEvent,
     ):
         """Add a plane widget to the scene.
 
@@ -279,7 +307,7 @@ class WidgetHelper:
             The starting normal vector of the plane.
 
         origin : tuple(float)
-            The starting coordinate of the center of the place.
+            The starting coordinate of the center of the plane.
 
         bounds : tuple(float)
             Length 6 tuple of the bounding box where the widget is placed.
@@ -327,15 +355,15 @@ class WidgetHelper:
             rotating the normal. This is forced to ``False`` when
             ``assign_to_axis`` is set.
 
+        interaction_event : vtk.vtkCommand.EventIds, optional
+            The VTK interaction event to use for triggering the callback.
+
         Returns
         -------
         vtk.vtkImplicitPlaneWidget or vtk.vtkPlaneWidget
             Plane widget.
 
         """
-        if not hasattr(self, "plane_widgets"):
-            self.plane_widgets = []
-
         if origin is None:
             origin = self.center
         if bounds is None:
@@ -375,7 +403,7 @@ class WidgetHelper:
 
             plane_widget.SetDrawPlane(False)
             plane_widget.AddObserver(_vtk.vtkCommand.StartInteractionEvent, _start_interact)
-            plane_widget.AddObserver(_vtk.vtkCommand.EndInteractionEvent, _stop_interact)
+            plane_widget.AddObserver(interaction_event, _stop_interact)
             plane_widget.SetPlaceFactor(factor)
             plane_widget.PlaceWidget(bounds)
             plane_widget.SetOrigin(origin)
@@ -436,7 +464,7 @@ class WidgetHelper:
         plane_widget.Modified()
         plane_widget.UpdatePlacement()
         plane_widget.On()
-        plane_widget.AddObserver(_vtk.vtkCommand.EndInteractionEvent, _the_callback)
+        plane_widget.AddObserver(interaction_event, _the_callback)
         if test_callback:
             _the_callback(plane_widget, None)  # Trigger immediate update
 
@@ -444,11 +472,8 @@ class WidgetHelper:
         return plane_widget
 
     def clear_plane_widgets(self):
-        """Disable all of the plane widgets."""
-        if hasattr(self, 'plane_widgets'):
-            for widget in self.plane_widgets:
-                widget.Off()
-            del self.plane_widgets
+        """Remove all of the plane widgets."""
+        self.plane_widgets.clear()
 
     def add_mesh_clip_plane(
         self,
@@ -464,6 +489,8 @@ class WidgetHelper:
         implicit=True,
         normal_rotation=True,
         crinkle=False,
+        interaction_event=_vtk.vtkCommand.EndInteractionEvent,
+        origin=None,
         **kwargs,
     ):
         """Clip a mesh using a plane widget.
@@ -523,6 +550,12 @@ class WidgetHelper:
         crinkle : bool, optional
             Crinkle the clip by extracting the entire cells along the clip.
 
+        interaction_event : vtk.vtkCommand.EventIds, optional
+            The VTK interaction event to use for triggering the callback.
+
+        origin : tuple(float), optional
+            The starting coordinate of the center of the plane.
+
         **kwargs : dict, optional
             All additional keyword arguments are passed to
             :func:`BasePlotter.add_mesh` to control how the mesh is
@@ -540,8 +573,10 @@ class WidgetHelper:
         rng = mesh.get_data_range(kwargs.get('scalars', None))
         kwargs.setdefault('clim', kwargs.pop('rng', rng))
         mesh.set_active_scalars(kwargs.get('scalars', mesh.active_scalars_name))
+        if origin is None:
+            origin = mesh.center
 
-        self.add_mesh(mesh.outline(), name=name + "outline", opacity=0.0)
+        self.add_mesh(mesh.outline(), name=f"{name}-outline", opacity=0.0)
 
         if crinkle:
             mesh.cell_data['cell_ids'] = np.arange(0, mesh.n_cells, dtype=int)
@@ -557,13 +592,11 @@ class WidgetHelper:
         alg.SetValue(value)
         alg.SetInsideOut(invert)  # invert the clip if needed
 
-        if not hasattr(self, "plane_clipped_meshes"):
-            self.plane_clipped_meshes = []
         plane_clipped_mesh = _get_output(alg)
         self.plane_clipped_meshes.append(plane_clipped_mesh)
 
-        def callback(normal, origin):
-            function = generate_plane(normal, origin)
+        def callback(normal, loc):
+            function = generate_plane(normal, loc)
             alg.SetClipFunction(function)  # the implicit function
             alg.Update()  # Perform the Cut
             clipped = pyvista.wrap(alg.GetOutput())
@@ -582,8 +615,9 @@ class WidgetHelper:
             origin_translation=origin_translation,
             outline_translation=outline_translation,
             implicit=implicit,
-            origin=mesh.center,
+            origin=origin,
             normal_rotation=normal_rotation,
+            interaction_event=interaction_event,
         )
 
         return self.add_mesh(plane_clipped_mesh, **kwargs)
@@ -600,6 +634,8 @@ class WidgetHelper:
         outline_translation=False,
         implicit=True,
         normal_rotation=True,
+        interaction_event=_vtk.vtkCommand.EndInteractionEvent,
+        origin=None,
         **kwargs,
     ):
         """Slice a mesh using a plane widget.
@@ -652,6 +688,12 @@ class WidgetHelper:
             effectively disabled. This prevents the user from rotating the
             normal. This is forced to ``False`` when ``assign_to_axis`` is set.
 
+        interaction_event : vtk.vtkCommand.EventIds, optional
+            The VTK interaction event to use for triggering the callback.
+
+        origin : tuple(float), optional
+            The starting coordinate of the center of the plane.
+
         **kwargs : dict, optional
             All additional keyword arguments are passed to
             :func:`BasePlotter.add_mesh` to control how the mesh is
@@ -667,16 +709,16 @@ class WidgetHelper:
         rng = mesh.get_data_range(kwargs.get('scalars', None))
         kwargs.setdefault('clim', kwargs.pop('rng', rng))
         mesh.set_active_scalars(kwargs.get('scalars', mesh.active_scalars_name))
+        if origin is None:
+            origin = mesh.center
 
-        self.add_mesh(mesh.outline(), name=name + "outline", opacity=0.0)
+        self.add_mesh(mesh.outline(), name=f"{name}-outline", opacity=0.0)
 
         alg = _vtk.vtkCutter()  # Construct the cutter object
         alg.SetInputDataObject(mesh)  # Use the grid as the data we desire to cut
         if not generate_triangles:
             alg.GenerateTrianglesOff()
 
-        if not hasattr(self, "plane_sliced_meshes"):
-            self.plane_sliced_meshes = []
         plane_sliced_mesh = pyvista.wrap(alg.GetOutput())
         self.plane_sliced_meshes.append(plane_sliced_mesh)
 
@@ -698,14 +740,21 @@ class WidgetHelper:
             origin_translation=origin_translation,
             outline_translation=outline_translation,
             implicit=implicit,
-            origin=mesh.center,
+            origin=origin,
             normal_rotation=normal_rotation,
+            interaction_event=interaction_event,
         )
 
         return self.add_mesh(plane_sliced_mesh, **kwargs)
 
     def add_mesh_slice_orthogonal(
-        self, mesh, generate_triangles=False, widget_color=None, tubing=False, **kwargs
+        self,
+        mesh,
+        generate_triangles=False,
+        widget_color=None,
+        tubing=False,
+        interaction_event=_vtk.vtkCommand.EndInteractionEvent,
+        **kwargs,
     ):
         """Slice a mesh with three interactive planes.
 
@@ -734,6 +783,9 @@ class WidgetHelper:
             When using an implicit plane wiget, this controls whether or not
             tubing is shown around the plane's boundaries.
 
+        interaction_event : vtk.vtkCommand.EventIds, optional
+            The VTK interaction event to use for triggering the callback.
+
         **kwargs : dict, optional
             All additional keyword arguments are passed to
             :func:`BasePlotter.add_mesh` to control how the mesh is
@@ -746,7 +798,11 @@ class WidgetHelper:
 
         """
         actors = []
+        name = kwargs.pop("name", None)
         for ax in ["x", "y", "z"]:
+            axkwargs = kwargs.copy()
+            if name:
+                axkwargs["name"] = f"{name}-{ax}"
             a = self.add_mesh_slice(
                 mesh,
                 assign_to_axis=ax,
@@ -755,7 +811,8 @@ class WidgetHelper:
                 generate_triangles=generate_triangles,
                 widget_color=widget_color,
                 tubing=tubing,
-                **kwargs,
+                interaction_event=interaction_event,
+                **axkwargs,
             )
             actors.append(a)
 
@@ -770,6 +827,7 @@ class WidgetHelper:
         color=None,
         use_vertices=False,
         pass_widget=False,
+        interaction_event=_vtk.vtkCommand.EndInteractionEvent,
     ):
         """Add a line widget to the scene.
 
@@ -807,15 +865,15 @@ class WidgetHelper:
             If ``True``, the widget will be passed as the last
             argument of the callback.
 
+        interaction_event : vtk.vtkCommand.EventIds, optional
+            The VTK interaction event to use for triggering the callback.
+
         Returns
         -------
         vtk.vtkLineWidget
             Created line widget.
 
         """
-        if not hasattr(self, "line_widgets"):
-            self.line_widgets = []
-
         if bounds is None:
             bounds = self.bounds
 
@@ -843,18 +901,15 @@ class WidgetHelper:
         line_widget.SetResolution(resolution)
         line_widget.Modified()
         line_widget.On()
-        line_widget.AddObserver(_vtk.vtkCommand.EndInteractionEvent, _the_callback)
+        line_widget.AddObserver(interaction_event, _the_callback)
         _the_callback(line_widget, None)
 
         self.line_widgets.append(line_widget)
         return line_widget
 
     def clear_line_widgets(self):
-        """Disable all of the line widgets."""
-        if hasattr(self, 'line_widgets'):
-            for widget in self.line_widgets:
-                widget.Off()
-            del self.line_widgets
+        """Remove all of the line widgets."""
+        self.line_widgets.clear()
 
     def add_text_slider_widget(
         self,
@@ -1074,9 +1129,6 @@ class WidgetHelper:
         ... )
         >>> pl.show()
         """
-        if not hasattr(self, "slider_widgets"):
-            self.slider_widgets = []
-
         if value is None:
             value = ((rng[1] - rng[0]) / 2) + rng[0]
 
@@ -1164,11 +1216,8 @@ class WidgetHelper:
         return slider_widget
 
     def clear_slider_widgets(self):
-        """Disable all of the slider widgets."""
-        if hasattr(self, 'slider_widgets'):
-            for widget in self.slider_widgets:
-                widget.Off()
-            del self.slider_widgets
+        """Remove all of the slider widgets."""
+        self.slider_widgets.clear()
 
     def add_mesh_threshold(
         self,
@@ -1214,9 +1263,9 @@ class WidgetHelper:
         preference : str, optional
             When ``mesh.n_points == mesh.n_cells`` and setting
             scalars, this parameter sets how the scalars will be
-            mapped to the mesh.  Default ``'points'``, causes the
-            scalars will be associated with the mesh points.  Can be
-            either ``'points'`` or ``'cells'``.
+            mapped to the mesh.  Default ``'cell'``, causes the
+            scalars to be associated with the mesh cells.  Can be
+            either ``'point'`` or ``'cell'``.
 
         title : str, optional
             The string label of the slider widget.
@@ -1261,7 +1310,7 @@ class WidgetHelper:
             title = scalars
         mesh.set_active_scalars(scalars)
 
-        self.add_mesh(mesh.outline(), name=name + "outline", opacity=0.0)
+        self.add_mesh(mesh.outline(), name=f"{name}-outline", opacity=0.0)
 
         alg = _vtk.vtkThreshold()
         alg.SetInputDataObject(mesh)
@@ -1270,8 +1319,6 @@ class WidgetHelper:
         )  # args: (idx, port, connection, field, name)
         alg.SetUseContinuousCellRange(continuous)
 
-        if not hasattr(self, "threshold_meshes"):
-            self.threshold_meshes = []
         threshold_mesh = pyvista.wrap(alg.GetOutput())
         self.threshold_meshes.append(threshold_mesh)
 
@@ -1293,7 +1340,7 @@ class WidgetHelper:
         )
 
         kwargs.setdefault("reset_camera", False)
-        self.add_mesh(threshold_mesh, scalars=scalars, **kwargs)
+        return self.add_mesh(threshold_mesh, scalars=scalars, **kwargs)
 
     def add_mesh_isovalue(
         self,
@@ -1344,9 +1391,9 @@ class WidgetHelper:
         preference : str, optional
             When ``mesh.n_points == mesh.n_cells`` and setting
             scalars, this parameter sets how the scalars will be
-            mapped to the mesh.  Default ``'points'``, causes the
+            mapped to the mesh.  Default ``'point'``, causes the
             scalars will be associated with the mesh points.  Can be
-            either ``'points'`` or ``'cells'``.
+            either ``'point'`` or ``'cell'``.
 
         title : str, optional
             The string label of the slider widget.
@@ -1409,10 +1456,8 @@ class WidgetHelper:
         alg.SetInputArrayToProcess(0, 0, 0, field.value, scalars)
         alg.SetNumberOfContours(1)  # Only one contour level
 
-        self.add_mesh(mesh.outline(), name=name + "outline", opacity=0.0)
+        self.add_mesh(mesh.outline(), name=f"{name}-outline", opacity=0.0)
 
-        if not hasattr(self, "isovalue_meshes"):
-            self.isovalue_meshes = []
         isovalue_mesh = pyvista.wrap(alg.GetOutput())
         self.isovalue_meshes.append(isovalue_mesh)
 
@@ -1447,6 +1492,7 @@ class WidgetHelper:
         pass_widget=False,
         closed=False,
         initial_points=None,
+        interaction_event=_vtk.vtkCommand.EndInteractionEvent,
     ):
         """Create and add a spline widget to the scene.
 
@@ -1501,6 +1547,9 @@ class WidgetHelper:
             last point are the same, this will be a closed loop
             spline.
 
+        interaction_event : vtk.vtkCommand.EventIds, optional
+            The VTK interaction event to use for triggering the callback.
+
         Returns
         -------
         vtk.vtkSplineWidget
@@ -1515,9 +1564,6 @@ class WidgetHelper:
         if initial_points is not None and len(initial_points) != n_handles:
             raise ValueError("`initial_points` must be length `n_handles`.")
 
-        if not hasattr(self, "spline_widgets"):
-            self.spline_widgets = []
-
         color = Color(color, default_color=pyvista.global_theme.color)
 
         if bounds is None:
@@ -1552,7 +1598,7 @@ class WidgetHelper:
             spline_widget.SetClosed(closed)
         spline_widget.Modified()
         spline_widget.On()
-        spline_widget.AddObserver(_vtk.vtkCommand.EndInteractionEvent, _the_callback)
+        spline_widget.AddObserver(interaction_event, _the_callback)
         _the_callback(spline_widget, None)
 
         if show_ribbon:
@@ -1562,11 +1608,8 @@ class WidgetHelper:
         return spline_widget
 
     def clear_spline_widgets(self):
-        """Disable all of the spline widgets."""
-        if hasattr(self, 'spline_widgets'):
-            for widget in self.spline_widgets:
-                widget.Off()
-            del self.spline_widgets
+        """Remove all of the spline widgets."""
+        self.spline_widgets.clear()
 
     def add_mesh_slice_spline(
         self,
@@ -1580,6 +1623,7 @@ class WidgetHelper:
         ribbon_opacity=0.5,
         initial_points=None,
         closed=False,
+        interaction_event=_vtk.vtkCommand.EndInteractionEvent,
         **kwargs,
     ):
         """Slice a mesh with a spline widget.
@@ -1634,6 +1678,9 @@ class WidgetHelper:
         closed : bool, optional
             Make the spline a closed loop.
 
+        interaction_event : vtk.vtkCommand.EventIds, optional
+            The VTK interaction event to use for triggering the callback.
+
         **kwargs : dict, optional
             All additional keyword arguments are passed to
             :func:`BasePlotter.add_mesh` to control how the mesh is
@@ -1645,20 +1692,20 @@ class WidgetHelper:
             VTK actor of the mesh.
 
         """
-        name = kwargs.get('name', mesh.memory_address)
+        name = kwargs.get('name', None)
+        if name is None:
+            name = mesh.memory_address
         rng = mesh.get_data_range(kwargs.get('scalars', None))
         kwargs.setdefault('clim', kwargs.pop('rng', rng))
         mesh.set_active_scalars(kwargs.get('scalars', mesh.active_scalars_name))
 
-        self.add_mesh(mesh.outline(), name=name + "outline", opacity=0.0)
+        self.add_mesh(mesh.outline(), name=f"{name}-outline", opacity=0.0)
 
         alg = _vtk.vtkCutter()  # Construct the cutter object
         alg.SetInputDataObject(mesh)  # Use the grid as the data we desire to cut
         if not generate_triangles:
             alg.GenerateTrianglesOff()
 
-        if not hasattr(self, "spline_sliced_meshes"):
-            self.spline_sliced_meshes = []
         spline_sliced_mesh = pyvista.wrap(alg.GetOutput())
         self.spline_sliced_meshes.append(spline_sliced_mesh)
 
@@ -1683,6 +1730,7 @@ class WidgetHelper:
             ribbon_opacity=ribbon_opacity,
             initial_points=initial_points,
             closed=closed,
+            interaction_event=interaction_event,
         )
 
         return self.add_mesh(spline_sliced_mesh, **kwargs)
@@ -1700,6 +1748,7 @@ class WidgetHelper:
         indices=None,
         pass_widget=False,
         test_callback=True,
+        interaction_event=_vtk.vtkCommand.EndInteractionEvent,
     ):
         """Add one or many sphere widgets to a scene.
 
@@ -1758,15 +1807,15 @@ class WidgetHelper:
             If ``True``, run the callback function after the widget is
             created.
 
+        interaction_event : vtk.vtkCommand.EventIds, optional
+            The VTK interaction event to use for triggering the callback.
+
         Returns
         -------
         vtk.vtkSphereWidget
             The sphere widget.
 
         """
-        if not hasattr(self, "sphere_widgets"):
-            self.sphere_widgets = []
-
         if color is None:
             color = pyvista.global_theme.color.float_rgb
         selected_color = Color(selected_color)
@@ -1821,7 +1870,7 @@ class WidgetHelper:
             sphere_widget.SetPhiResolution(phi_resolution)
             sphere_widget.Modified()
             sphere_widget.On()
-            sphere_widget.AddObserver(_vtk.vtkCommand.EndInteractionEvent, _the_callback)
+            sphere_widget.AddObserver(interaction_event, _the_callback)
             self.sphere_widgets.append(sphere_widget)
 
         if test_callback is True:
@@ -1833,11 +1882,8 @@ class WidgetHelper:
         return sphere_widget
 
     def clear_sphere_widgets(self):
-        """Disable all of the sphere widgets."""
-        if hasattr(self, 'sphere_widgets'):
-            for widget in self.sphere_widgets:
-                widget.Off()
-            del self.sphere_widgets
+        """Remove all of the sphere widgets."""
+        self.sphere_widgets.clear()
 
     def add_checkbox_button_widget(
         self,
@@ -1888,9 +1934,22 @@ class WidgetHelper:
         vtk.vtkButtonWidget
             The VTK button widget configured as a checkbox button.
 
+        Examples
+        --------
+        The following example generates a static image of the widget.
+
+        >>> import pyvista as pv
+        >>> mesh = pv.Sphere()
+        >>> p = pv.Plotter()
+        >>> actor = p.add_mesh(mesh)
+        >>> def toggle_vis(flag):
+        ...     actor.SetVisibility(flag)
+        >>> _ = p.add_checkbox_button_widget(toggle_vis, value=True)
+        >>> p.show()
+
+        Download the interactive example at :ref:`checkbox_widget_example`.
+
         """
-        if not hasattr(self, "button_widgets"):
-            self.button_widgets = []
 
         def create_button(color1, color2, color3, dims=(size, size, 1)):
             color1 = np.array(Color(color1).int_rgb)
@@ -1970,21 +2029,16 @@ class WidgetHelper:
         widget.SetAnimate(animate)
         widget.SetAnimatorTotalFrames(n_frames)
         widget.On()
-        self._camera_widgets.append(widget)
+        self.camera_widgets.append(widget)
         return widget
 
     def clear_camera_widgets(self):
-        """Disable all of the camera widgets."""
-        for widget in self._camera_widgets:
-            widget.Off()
-        self._camera_widgets = []
+        """Remove all of the camera widgets."""
+        self.camera_widgets.clear()
 
     def clear_button_widgets(self):
-        """Disable all of the button widgets."""
-        if hasattr(self, 'button_widgets'):
-            for widget in self.button_widgets:
-                widget.Off()
-            del self.button_widgets
+        """Remove all of the button widgets."""
+        self.button_widgets.clear()
 
     def close(self):
         """Close the widgets."""
