@@ -1,6 +1,6 @@
 """Common functions."""
 import collections.abc
-from typing import Union
+from typing import Tuple, Union
 
 import numpy as np
 
@@ -8,8 +8,8 @@ from pyvista._typing import NumericArray, VectorArray
 
 
 def _coerce_pointslike_arg(
-    points: Union[NumericArray, VectorArray], copy: bool = True
-) -> np.ndarray:
+    points: Union[NumericArray, VectorArray], copy: bool = False
+) -> Tuple[np.ndarray, bool]:
     """Check and coerce arg to (n, 3) np.ndarray.
 
     Parameters
@@ -25,6 +25,8 @@ def _coerce_pointslike_arg(
     -------
     np.ndarray
         Size (n, 3) array.
+    bool
+        Whether the input was a single point in an array-like with shape (3,).
 
     """
     if isinstance(points, collections.abc.Sequence):
@@ -35,14 +37,18 @@ def _coerce_pointslike_arg(
 
     if points.ndim > 2:
         raise ValueError("Array of points must be 1D or 2D")
+
     if points.ndim == 2:
         if points.shape[1] != 3:
             raise ValueError("Array of points must have three values per point (shape (n, 3))")
+        singular = False
+
     else:
         if points.size != 3:
             raise ValueError("Given point must have three values")
+        singular = True
         points = np.reshape(points, [1, 3])
 
     if copy:
-        return points.copy()
-    return points
+        return points.copy(), singular
+    return points, singular
