@@ -4,9 +4,11 @@ from dataclasses import dataclass
 from functools import wraps
 import os
 import pathlib
-from typing import Any, List
+from typing import Any, Callable, List, Union
 from xml.etree import ElementTree
 
+import numpy as np
+
 import pyvista
 from pyvista import _vtk
 from pyvista.utilities import abstract_class, wrap
@@ -44,6 +46,8 @@ def get_reader(filename, force_ext=None):
     +----------------+---------------------------------------------+
     | ``.g``         | :class:`pyvista.BYUReader`                  |
     +----------------+---------------------------------------------+
+    | ``.gif``       | :class:`pyvista.GIFReader`                  |
+    +----------------+---------------------------------------------+
     | ``.glb``       | :class:`pyvista.GLTFReader`                 |
     +----------------+---------------------------------------------+
     | ``.gltf``      | :class:`pyvista.GLTFReader`                 |
@@ -810,10 +814,7 @@ class OpenFOAMReader(BaseReader, PointCellDataSelection, TimeReader):
 
     @decompose_polyhedra.setter
     def decompose_polyhedra(self, value):
-        if value:
-            self.reader.DecomposePolyhedraOn()
-        else:
-            self.reader.DecomposePolyhedraOff()
+        self.reader.SetDecomposePolyhedra(value)
 
     @property
     def skip_zero_time(self):
@@ -839,11 +840,7 @@ class OpenFOAMReader(BaseReader, PointCellDataSelection, TimeReader):
 
     @skip_zero_time.setter
     def skip_zero_time(self, value):
-        if value:
-            self.reader.SkipZeroTimeOn()
-        else:
-            self.reader.SkipZeroTimeOff()
-
+        self.reader.SetSkipZeroTime(value)
         self._update_information()
         self.reader.SetRefresh()
 
@@ -876,10 +873,7 @@ class OpenFOAMReader(BaseReader, PointCellDataSelection, TimeReader):
 
     @cell_to_point_creation.setter
     def cell_to_point_creation(self, value):
-        if value:
-            self.reader.CreateCellToPointOn()
-        else:
-            self.reader.CreateCellToPointOff()
+        self.reader.SetCreateCellToPoint(value)
 
     @property
     def number_patch_arrays(self):
@@ -2078,6 +2072,85 @@ class SegYReader(BaseReader):
     _class_reader = staticmethod(_vtk.lazy_vtkSegYReader)
 
 
+class _GIFReader:
+    """Simulate a VTK reader for GIF files."""
+
+    _data_object = None
+    _observers: List[Union[int, Callable]] = []
+    _n_frames = 0
+    _current_frame = 0
+
+    def SetFileName(self, filename):
+        """Needed for VTK-like compatibility with BaseReader."""
+        self._filename = filename
+
+    def UpdateInformation(self):
+        """Needed for VTK-like compatibility with BaseReader."""
+        pass
+
+    def AddObserver(self, event_type, callback):
+        """Needed for VTK-like compatibility with BaseReader."""
+        self._observers.append([event_type, callback])
+
+    def RemoveObservers(self, *args):
+        """Needed for VTK-like compatibility with BaseReader."""
+        self._observers = []
+
+    def GetProgress(self):
+        return self._current_frame / self._n_frames
+
+    def UpdateObservers(self, event_type):
+        for event_type_allowed, observer in self._observers:
+            if event_type_allowed == event_type:
+                observer(self, event_type)
+
+    def Update(self):
+        """Read the GIF and store internally to `_data_object`."""
+        from PIL import Image, ImageSequence
+
+        img = Image.open(self._filename)
+        self._data_object = pyvista.UniformGrid(dims=(img.size[0], img.size[1], 1))
+
+        # load each frame to the grid (RGB since gifs do not support transparency
+        self._n_frames = img.n_frames
+        for i, frame in enumerate(ImageSequence.Iterator(img)):
+            self._current_frame = i
+            data = np.array(frame.convert('RGB').getdata(), dtype=np.uint8)
+            self._data_object.point_data.set_array(data, f'frame{i}')
+            self.UpdateObservers(6)
+
+        if 'frame0' in self._data_object.point_data:
+            self._data_object.point_data.active_scalars_name = 'frame0'
+
+    def GetOutputDataObject(self, *args):
+        """Needed for VTK-like compatibility with BaseReader."""
+        return self._data_object
+
+
+class GIFReader(BaseReader):
+    """GIFReader for .gif files.
+
+    Parameters
+    ----------
+    path : str
+        Path of the GIF to read.
+
+    Examples
+    --------
+    >>> import pyvista
+    >>> from pyvista import examples
+    >>> filename = examples.download_gif_simple(load=False)
+    >>> filename.split("/")[-1]  # omit the path
+    'sample.gif'
+    >>> reader = pyvista.get_reader(filename)
+    >>> mesh = reader.read()
+    >>> mesh.plot(rgba=True, zoom='tight', border=True, border_width=2)
+
+    """
+
+    _class_reader = _GIFReader
+
+
 CLASS_READERS = {
     # Standard dataset readers:
     '.bmp': BMPReader,
@@ -2090,6 +2163,7 @@ CLASS_READERS = {
     '.facet': FacetReader,
     '.foam': POpenFOAMReader,
     '.g': BYUReader,
+    '.gif': GIFReader,
     '.glb': GLTFReader,
     '.gltf': GLTFReader,
     '.img': DICOMReader,
